# 3gpp_asn1

Decode the asn1 in docx

```sh
# download the docx

python decode_asn1.py file.docx output.asn1
# or
python decode_asn1.py file.docx > output.asn1
```

Question for @3gpp: why `docx` from for the specification ?
